##########
Change Log
##########

[0.1.0] - (Unreleased)
======================

- Initial version.
- ``metald.github.auth`` module support GitHub authentication using their integrations API.
- ``metald.tex.lsstdoc`` supports data scraping from LSST LaTeX documents based on the ``lsstdoc`` class from `lsst-texmf`_.

.. _lsst-texmf: https://lsst-texmf.lsst.io
